#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import sys

outputVerboseFlag = False
extractNullTerminatedXMLFlag = False
noPrettyXMLFlag = False
ERR_CODE_NO_IMAGES = -7
UTF8_ENCODING = "UTF-8"
PYTHON_VERSION = sys.version
PYTHON_2 = "2"
PYTHON_3 = "3"
